@@ -8,7 +8,7 @@
 
 #include <asm/types.h>          /* For __uXX types */
 
-#define IP_VS_VERSION_CODE            0x000907
+#define IP_VS_VERSION_CODE            0x000908
 #define NVERSION(version)                       \
 	(version >> 16) & 0xFF,                 \
 	(version >> 8) & 0xFF,                  \
@@ -329,6 +329,7 @@ enum {
 	NET_IPV4_VS_CACHE_BYPASS=22,
 	NET_IPV4_VS_EXPIRE_NODEST_CONN=23,
 	NET_IPV4_VS_SYNC_THRESHOLD=24,
+	NET_IPV4_VS_NAT_ICMP_SEND=25,
 	NET_IPV4_VS_LAST
 };
 
@@ -703,9 +704,9 @@ extern int sysctl_use_dst;
 extern int sysctl_ip_vs_cache_bypass;
 extern int sysctl_ip_vs_expire_nodest_conn;
 extern int sysctl_ip_vs_sync_threshold;
+extern int sysctl_ip_vs_nat_icmp_send;
 extern atomic_t ip_vs_dropentry;
 extern struct ip_vs_stats ip_vs_stats;
-extern rwlock_t __ip_vs_svc_lock;
 
 extern struct ip_vs_service *ip_vs_service_get(__u32 fwmark,
 					       __u16 protocol,
