@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_core.c,v 1.25 2001/11/23 14:34:10 wensong Exp $
+ * Version:     $Id: ip_vs_core.c,v 1.26 2001/12/11 12:41:29 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -677,7 +677,8 @@ static unsigned int ip_vs_out(unsigned int hooknum,
 	cp = ip_vs_conn_out_get(iph->protocol, iph->saddr, h.portp[0],
 				iph->daddr, h.portp[1]);
 	if (!cp) {
-		if (ip_vs_lookup_real_service(iph->protocol,
+		if (sysctl_ip_vs_nat_icmp_send &&
+		    ip_vs_lookup_real_service(iph->protocol,
 					      iph->saddr, h.portp[0])) {
 			/*
 			 * Notify the real server: there is no existing
@@ -1053,10 +1054,10 @@ static unsigned int ip_vs_in(unsigned int hooknum,
 	cp = ip_vs_conn_in_get(iph->protocol, iph->saddr, h.portp[0],
 			       iph->daddr, h.portp[1]);
 
-	if (!cp
-	    && (h.th->syn || (iph->protocol!=IPPROTO_TCP))
-	    && (svc = ip_vs_service_get(skb->nfmark, iph->protocol,
-					iph->daddr, h.portp[1]))) {
+	if (!cp &&
+	    (h.th->syn || (iph->protocol!=IPPROTO_TCP)) &&
+	    (svc = ip_vs_service_get(skb->nfmark, iph->protocol,
+				     iph->daddr, h.portp[1]))) {
 		if (ip_vs_todrop()) {
 			/*
 			 * It seems that we are very loaded.
@@ -1125,10 +1126,10 @@ static unsigned int ip_vs_in(unsigned int hooknum,
 	/* increase its packet counter and check if it is needed
 	   to be synchronized */
 	atomic_inc(&cp->in_pkts);
-	if (ip_vs_sync_state == IP_VS_STATE_MASTER
-	    && (cp->protocol != IPPROTO_TCP
-		|| cp->state == IP_VS_S_ESTABLISHED)
-	    && (atomic_read(&cp->in_pkts) % 50 == sysctl_ip_vs_sync_threshold))
+	if (ip_vs_sync_state == IP_VS_STATE_MASTER &&
+	    (cp->protocol != IPPROTO_TCP ||
+	     cp->state == IP_VS_S_ESTABLISHED) &&
+	    (atomic_read(&cp->in_pkts) % 50 == sysctl_ip_vs_sync_threshold))
 		ip_vs_sync_conn(cp);
 
 	ip_vs_conn_put(cp);
