@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_timer.c,v 1.5 2001/05/09 15:01:15 wensong Exp $
+ * Version:     $Id: ip_vs_timer.c,v 1.6 2001/12/11 12:41:29 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Julian Anastasov <uli@linux.tu-varna.acad.bg>
@@ -107,16 +107,17 @@ static inline void internal_add_sltimer(struct timer_list *timer)
 	list_add(&timer->list, vec->prev);
 }
 
-rwlock_t __ip_vs_sltimerlist_lock = RW_LOCK_UNLOCKED;
+
+static spinlock_t __ip_vs_sltimerlist_lock = SPIN_LOCK_UNLOCKED;
 
 void add_sltimer(struct timer_list *timer)
 {
-	write_lock(&__ip_vs_sltimerlist_lock);
+	spin_lock(&__ip_vs_sltimerlist_lock);
 	if (timer->list.next)
 		goto bug;
 	internal_add_sltimer(timer);
   out:
-	write_unlock(&__ip_vs_sltimerlist_lock);
+	spin_unlock(&__ip_vs_sltimerlist_lock);
 	return;
 
   bug:
@@ -137,21 +138,21 @@ void mod_sltimer(struct timer_list *timer, unsigned long expires)
 {
 	int ret;
 
-	write_lock(&__ip_vs_sltimerlist_lock);
+	spin_lock(&__ip_vs_sltimerlist_lock);
 	timer->expires = expires;
 	ret = detach_sltimer(timer);
 	internal_add_sltimer(timer);
-	write_unlock(&__ip_vs_sltimerlist_lock);
+	spin_unlock(&__ip_vs_sltimerlist_lock);
 }
 
 int del_sltimer(struct timer_list * timer)
 {
 	int ret;
 
-	write_lock(&__ip_vs_sltimerlist_lock);
+	spin_lock(&__ip_vs_sltimerlist_lock);
 	ret = detach_sltimer(timer);
 	timer->list.next = timer->list.prev = 0;
-	write_unlock(&__ip_vs_sltimerlist_lock);
+	spin_unlock(&__ip_vs_sltimerlist_lock);
 	return ret;
 }
 
@@ -185,7 +186,7 @@ static inline void cascade_sltimers(struct sltimer_vec *tv)
 
 static inline void run_sltimer_list(void)
 {
-	write_lock(&__ip_vs_sltimerlist_lock);
+	spin_lock(&__ip_vs_sltimerlist_lock);
 	while ((long)(jiffies - sltimer_jiffies) >= 0) {
 		struct list_head *head, *curr;
 		if (!sltv1.index) {
@@ -208,27 +209,25 @@ static inline void run_sltimer_list(void)
 
 			detach_sltimer(timer);
 			timer->list.next = timer->list.prev = NULL;
-			write_unlock(&__ip_vs_sltimerlist_lock);
+			spin_unlock(&__ip_vs_sltimerlist_lock);
 			fn(data);
-			write_lock(&__ip_vs_sltimerlist_lock);
+			spin_lock(&__ip_vs_sltimerlist_lock);
 			goto repeat;
 		}
 		sltimer_jiffies += 1<<SHIFT_BITS;
 		sltv1.index = (sltv1.index + 1) & TVR_MASK;
 	}
-	write_unlock(&__ip_vs_sltimerlist_lock);
+	spin_unlock(&__ip_vs_sltimerlist_lock);
 }
 
-static void sltimer_handler(unsigned long data);
-
-struct timer_list slow_timer = { function: sltimer_handler };
+static struct timer_list slow_timer;
 
 /*
  *  Slow timer handler is activated every second
  */
 #define SLTIMER_PERIOD	     1*HZ
 
-void sltimer_handler(unsigned long data)
+static void sltimer_handler(unsigned long data)
 {
 	run_sltimer_list();
 
@@ -246,6 +245,9 @@ void ip_vs_sltimer_init(void)
 	 * Hook the slow_timer handler in the system timer.
 	 */
 	init_sltimervecs();
+
+	init_timer(&slow_timer);
+	slow_timer.function = sltimer_handler;
 	slow_timer.expires = jiffies+SLTIMER_PERIOD;
 	add_timer(&slow_timer);
 }
@@ -253,5 +255,5 @@ void ip_vs_sltimer_init(void)
 
 void ip_vs_sltimer_cleanup(void)
 {
-	del_timer(&slow_timer);
+	del_timer_sync(&slow_timer);
 }
